@@ -9,7 +9,7 @@ use std::{fmt, fs, io};
 use crate::history::{db_extensions, schema};
 use crate::network::Network;
 use crate::path_update_helpers;
-use crate::settings::{HistoryFormat, Settings};
+use crate::settings::{HistoryFormat, ResultSort, Settings};
 use crate::simplified_command::SimplifiedCommand;
 use itertools::Itertools;
 use rusqlite::types::ToSql;
@@ -130,7 +130,7 @@ impl History {
         self.connection.execute_named("INSERT INTO commands (cmd, cmd_tpl, session_id, when_run, exit_code, selected, dir, old_dir) VALUES (:cmd, :cmd_tpl, :session_id, :when_run, :exit_code, :selected, :dir, :old_dir)",
                                       &[
                                           (":cmd", &command.to_owned()),
-                                          (":cmd_tpl", &simplified_command.result.to_owned()),
+                                          (":cmd_tpl", &simplified_command.result),
                                           (":session_id", &session_id.to_owned()),
                                           (":when_run", &when_run.to_owned()),
                                           (":exit_code", &exit_code.to_owned()),
@@ -234,7 +234,13 @@ impl History {
         }
     }
 
-    pub fn find_matches(&self, cmd: &str, num: i16, fuzzy: bool) -> Vec<Command> {
+    pub fn find_matches(
+        &self,
+        cmd: &str,
+        num: i16,
+        fuzzy: bool,
+        result_sort: &ResultSort,
+    ) -> Vec<Command> {
         let mut like_query = "%".to_string();
 
         if fuzzy {
@@ -243,15 +249,26 @@ impl History {
             like_query.push_str(cmd);
         }
 
-        like_query.push_str("%");
+        like_query.push('%');
+
+        let order_by_column: &str = match &result_sort {
+            ResultSort::LastRun => "last_run",
+            _ => "rank",
+        };
+
+        let query: &str = &format!(
+            "{} {} {} {}",
+            "SELECT id, cmd, cmd_tpl, session_id, when_run, exit_code, selected, dir, rank,
+                age_factor, length_factor, exit_factor, recent_failure_factor,
+                selected_dir_factor, dir_factor, overlap_factor, immediate_overlap_factor,
+                selected_occurrences_factor, occurrences_factor, last_run
+            FROM contextual_commands
+            WHERE cmd LIKE (:like)",
+            "ORDER BY",
+            order_by_column,
+            "DESC LIMIT :limit"
+        )[..];
 
-        let query = "SELECT id, cmd, cmd_tpl, session_id, when_run, exit_code, selected, dir, rank,
-                              age_factor, length_factor, exit_factor, recent_failure_factor,
-                              selected_dir_factor, dir_factor, overlap_factor, immediate_overlap_factor,
-                              selected_occurrences_factor, occurrences_factor, last_run
-                      FROM contextual_commands
-                      WHERE cmd LIKE (:like)
-                      ORDER BY rank DESC LIMIT :limit";
         let mut statement = self
             .connection
             .prepare(query)
@@ -277,7 +294,7 @@ impl History {
                                     return true;
                                 }
 
-                                return false;
+                                false
                             })
                             .map(|m| m.0);
 
@@ -391,7 +408,7 @@ impl History {
                     let b_mod = 1.0 - b_len as f64 / (a_len + b_len) as f64;
 
                     PartialOrd::partial_cmp(&(b.rank + b_mod), &(a.rank + a_mod))
-                        .unwrap_or_else(|| Ordering::Equal)
+                        .unwrap_or(Ordering::Equal)
                 })
                 .collect()
         }
@@ -619,10 +636,8 @@ impl History {
             .unwrap_or_else(|err| panic!("McFly error: Query Map to work ({})", err));
 
         let mut vec = Vec::new();
-        for result in command_iter {
-            if let Ok(command) = result {
-                vec.push(command);
-            }
+        for command in command_iter.flatten() {
+            vec.push(command);
         }
 
         vec
